##  Step 1: Create Tag Groups
Create the necessary tag groups with tags according to your organization's requirements. To learn how to manage tag groups in SAP LeanIX, see [Tagging](https://help.sap.com/docs/leanix/ea/tagging?locale=en-US&state=PRODUCTION&version=CLOUD "This guide covers the essential steps for managing tags, including creating tag groups, adding and editing tags within those groups, and deleting tags and tag groups. Suggest Edits Introduction").
In our example scenario, we need to create two tag groups, as shown in the following table. Restrict each group to a specific fact sheet type and set the group mode to Single.
Tag Group | Tags
---|---
IT component tag |
  * Server
  * Database


Application tag |
  * Linked_to_Server
  * Linked_to_Database




**Note**
In this tutorial, we assume that tags are already assigned to IT component fact sheets.
